@@ -6,7 +6,7 @@ use warnings;
 use SemVer;
 use JSON;
 use Carp qw(croak);
-our $VERSION = v0.15.0;
+our $VERSION = v0.16.0;
 
 =head1 Name
 
@@ -762,11 +762,11 @@ __END__
 =head1 Support
 
 This module is stored in an open L<GitHub
-repository|http://github.com/theory/pgxn-meta/>. Feel free to fork and
+repository|http://github.com/pgxn/pgxn-meta/>. Feel free to fork and
 contribute!
 
 Please file bug reports via L<GitHub
-Issues|http://github.com/theory/pgxn-meta/issues/> or by sending mail to
+Issues|http://github.com/pgxn/pgxn-meta/issues/> or by sending mail to
 L<bug-PGXN-Meta@rt.cpan.org|mailto:bug-PGXN-Meta@rt.cpan.org>.
 
 =cut
